nsw-fuel-api-client
============================================
[![](https://travis-ci.org/nickw444/nsw-fuel-api-client.svg?branch=master)](https://travis-ci.org/nickw444/nsw-fuel-api-client)
[![](https://coveralls.io/repos/nickw444/nsw-fuel-api-client/badge.svg)](https://coveralls.io/r/nickw444/nsw-fuel-api-client)
[![](https://img.shields.io/pypi/v/nsw-fuel-api-client.svg)](https://pypi.python.org/pypi/nsw-fuel-api-client/)
    
API Client for NSW fuel prices.
